/*
   Copyright 2014-now by Alain Stalder. Made in Switzerland.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       https://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/

package ch.artecat.grengine.code;

import ch.artecat.grengine.except.CompileException;
import ch.artecat.grengine.sources.Sources;


/**
 * Compiler.
 * 
 * @since 1.0
 * 
 * @author Alain Stalder
 * @author Made in Switzerland.
 */
public interface Compiler {
    
    /**
     * compiles the given sources to an instance of {@link Code} in memory.
     *
     * @param sources sources
     *
     * @return compiled code
     * @throws CompileException if compilation failed
     * 
     * @since 1.0
     */
    Code compile(Sources sources);

}
